# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: task.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntask.proto\"\x89\x02\n\tTaskInput\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\ttask_name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x11\n\tthreshold\x18\x06 \x01(\x03\x12\x16\n\x0ethreshold_unit\x18\x07 \x01(\t\x12\x37\n\x0f\x61\x64\x64itional_data\x18\x08 \x03(\x0b\x32\x1e.TaskInput.AdditionalDataEntry\x12\x0c\n\x04host\x18\t \x01(\t\x1a\x35\n\x13\x41\x64\x64itionalDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\nTaskOutput\x12+\n\x08response\x18\x01 \x03(\x0b\x32\x19.TaskOutput.ResponseEntry\x1a/\n\rResponseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x31\n\x04Task\x12)\n\x0eUpsertTaskInfo\x12\n.TaskInput\x1a\x0b.TaskOutputB\x0fZ\r./translationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\r./translation'
  _globals['_TASKINPUT_ADDITIONALDATAENTRY']._loaded_options = None
  _globals['_TASKINPUT_ADDITIONALDATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKOUTPUT_RESPONSEENTRY']._loaded_options = None
  _globals['_TASKOUTPUT_RESPONSEENTRY']._serialized_options = b'8\001'
  _globals['_TASKINPUT']._serialized_start=15
  _globals['_TASKINPUT']._serialized_end=280
  _globals['_TASKINPUT_ADDITIONALDATAENTRY']._serialized_start=227
  _globals['_TASKINPUT_ADDITIONALDATAENTRY']._serialized_end=280
  _globals['_TASKOUTPUT']._serialized_start=282
  _globals['_TASKOUTPUT']._serialized_end=388
  _globals['_TASKOUTPUT_RESPONSEENTRY']._serialized_start=341
  _globals['_TASKOUTPUT_RESPONSEENTRY']._serialized_end=388
  _globals['_TASK']._serialized_start=390
  _globals['_TASK']._serialized_end=439
# @@protoc_insertion_point(module_scope)
